/*
Title:    AndyPi ArduLight for Arduino Nano
Code by:  Andrew Wilsion http://andypi.co.uk
Date:     07-04-2014
Version:  1.1
Changes:  Updated code to make more than 1 LED possible

Hardware: 
WS2801 pixel strip: connected to Data Pin and Clock Pin 
Push to make button switch: connected to button pin & GND
Potentiometer controls speed of colour swirl change: connected to analogue pin 

*/

// include the FastLED library
#include "FastLED.h"

// Define the number of LEDs in the strip (1 in this case)
#define NUM_LEDS 1

// For led chips like Neopixels, which have a data line, ground, and power, you just
// need to define DATA_PIN.  For led chipsets that are SPI based (four wires - data, clock,
// ground, and power), like the LPD8806 define both DATA_PIN and CLOCK_PIN, 
// followed by the digital pin number you attach them to on the arduino (13 and 11)
#define DATA_PIN 13
#define CLOCK_PIN 11

// Define the array of leds
CRGB leds[NUM_LEDS];

// set constant - pushbutton pin number (Digital pin 2)
const int buttonPin = 2;    

// define variable for reading the pushbutton status
// counter for the number of button presses
int buttonPushCounter = 0; 
// current state of the button
int buttonState = 0;  
// previous state of the button
int lastButtonState = 0;   

// variable to store the value coming from the potentiometer
int val = 0;       

void setup() { 
      // Uncomment/edit one of the following lines for your leds arrangement.
      // FastLED.addLeds<TM1803, DATA_PIN, RGB>(leds, NUM_LEDS);
      // FastLED.addLeds<TM1804, DATA_PIN, RGB>(leds, NUM_LEDS);
      // FastLED.addLeds<TM1809, DATA_PIN, RGB>(leds, NUM_LEDS);
      // FastLED.addLeds<WS2811, DATA_PIN, RGB>(leds, NUM_LEDS);
      // FastLED.addLeds<WS2812, DATA_PIN, RGB>(leds, NUM_LEDS);
      // FastLED.addLeds<WS2812B, DATA_PIN, RGB>(leds, NUM_LEDS);
      // FastLED.addLeds<NEOPIXEL, DATA_PIN, RGB>(leds, NUM_LEDS);
      // FastLED.addLeds<UCS1903, DATA_PIN, RGB>(leds, NUM_LEDS);
      // FastLED.addLeds<SM16716, RGB>(leds, NUM_LEDS);
      // FastLED.addLeds<LPD8806, RGB>(leds, NUM_LEDS);
      // FastLED.addLeds<WS2801, DATA_PIN, CLOCK_PIN, RGB>(leds, NUM_LEDS);
      // FastLED.addLeds<SM16716, DATA_PIN, CLOCK_PIN, RGB>(leds, NUM_LEDS);
      // FastLED.addLeds<LPD8806, DATA_PIN, CLOCK_PIN, RGB>(leds, NUM_LEDS);
      
      FastLED.addLeds<WS2801, RGB>(leds, NUM_LEDS); //we're using WS2801
      
      // initialize the pushbutton pin as an input:
      pinMode(buttonPin, INPUT);     
}

void loop() { 

  // increment the myColour varaible by 1 each time through the loop
  // (this is continouly running and is used for mode 4, the colour swirl)
  for(int myColour=0; myColour < 255; myColour++){
  // find the current state of the button (if it has been pressed) by reading the digital pin
  buttonState = digitalRead(buttonPin);
    // read the value from analog pin 2 (the potentiometer) into val
    val = analogRead(2);    
    // map the value of the analog input (0-1023) to the values to choose between for the delay time (0-60)
    // this is used to determine how fast the colours swirl in mode 4
    int delayVar = map(val, 0, 1023, 0, 60); 


  // compare the buttonState to its previous state
  if (buttonState != lastButtonState) {
    // if the state has changed, increment the counter
    if (buttonState == HIGH) {
      // if the current state is HIGH then the button
      // went from off to on: so incremet the counter
        if (buttonPushCounter < 5){
             buttonPushCounter++;
        }
        // unless we've reached the final mode, then loop back to mode 0
        else if (buttonPushCounter = 5){
             buttonPushCounter=0;
         }
    else {
    }
    }
  }

// save the current state as the last state,
//for next time through the loop
  lastButtonState = buttonState;


// Mode 0; LED red
  if (buttonPushCounter == 0) {
     for(int dot = 0; dot < NUM_LEDS; dot++)
    {
    leds[dot] = CRGB::Red;
    }
    FastLED.show();
    } 
    
// Mode 1; LED green
   else if (buttonPushCounter == 1){
   for(int dot = 0; dot < NUM_LEDS; dot++)
   {
   leds[dot] = CRGB::Green;
   }
   FastLED.show();
  }
  
// Mode 2; LED blue
  else if (buttonPushCounter == 2){
    for(int dot = 0; dot < NUM_LEDS; dot++)
    {
   leds[dot] = CRGB::Blue;
    }
   FastLED.show();
  }
 
// Mode 3; LED white
  else if (buttonPushCounter == 3){
    for(int dot = 0; dot < NUM_LEDS; dot++)
    {
   leds[dot] = CRGB::White;
    }
   FastLED.show();
  }
  
// Mode 4; LED set to a hue stored in myColour variable
 else if (buttonPushCounter == 4){
   for(int dot = 0; dot < NUM_LEDS; dot++)
    {
   leds[dot].setHue(myColour);
    }
   FastLED.show(); 
   delay(delayVar);

// Mode 5; LED black (off)
 }
  else {
    for(int dot = 0; dot < NUM_LEDS; dot++)
    {
   leds[dot] = CRGB::Black;
    }
   FastLED.show();
  }
  
}
}
